@@ -6,11 +6,9 @@ from .configuration import *
 from .party import *
 from .invoice import *
 from .account import *
-from .lang import *
 
 def register():
     Pool.register(
-        Lang,
         Address,
         CashflowTemplate,
         Cashflow,
